@@ -25,10 +25,10 @@
  ***************************************************************************/
 #include "../curl_setup.h"
 
-#include "../bufq.h"
-
 #ifdef USE_HTTP3
 
+#include "../bufq.h"
+
 #define MAX_PKT_BURST         10
 #define MAX_UDP_PAYLOAD_SIZE  1452
 
@@ -53,11 +53,11 @@ typedef enum {
   CURL_H3_ERR_VERSION_FALLBACK = 0x0110,
 } vquic_h3_error;
 
-#ifndef CURL_DISABLE_VERBOSE_STRINGS
+#ifdef CURLVERBOSE
 const char *vquic_h3_err_str(uint64_t error_code);
 #else
 #define vquic_h3_err_str(x)   ""
-#endif /* CURL_DISABLE_VERBOSE_STRINGS */
+#endif /* CURLVERBOSE */
 
 struct cf_quic_ctx {
   curl_socket_t sockfd;               /* connected UDP socket */
@@ -121,8 +121,6 @@ CURLcode vquic_recv_packets(struct Curl_cfilter *cf,
                             size_t max_pkts,
                             vquic_recv_pkts_cb *recv_cb, void *userp);
 
-#endif /* !USE_HTTP3 */
-
 #ifdef USE_NGTCP2
 struct ngtcp2_mem;
 struct ngtcp2_mem *Curl_ngtcp2_mem(void);
@@ -132,4 +130,6 @@ struct nghttp3_mem;
 struct nghttp3_mem *Curl_nghttp3_mem(void);
 #endif
 
+#endif /* !USE_HTTP3 */
+
 #endif /* HEADER_CURL_VQUIC_QUIC_INT_H */
